==> petsc-3.21.0-2-x86_64.pkg.tar.zst: opt/petsc/linux-c-opt/lib/petsc/conf/reconfigure-linux-c-opt.py <==
#!/usr/bin/python3
if __name__ == '__main__':
  import sys
  import os
  sys.path.insert(0, os.path.abspath('config'))
  import configure
  configure_options = [
    '--prefix=/opt/petsc/linux-c-opt',
    '--with-bison=0',
    '--with-cmake=0',
    '--with-fftw=1',
    '--with-gsl=1',
    '--with-hdf5-fortran-bindings=1',
    '--with-hdf5=1',
    '--with-hypre-include=/usr/include/hypre',
    '--with-hypre-lib=/usr/lib/libHYPRE.so',
    '--with-libjpeg=1',
    '--with-metis=1',
    '--with-mpi-dir=/usr',
    '--with-mpi-f90module-visibility=0',
    '--with-mumps=1',
    '--with-netcdf=1',
    '--with-parmetis=1',
    '--with-petsc4py=1',
    '--with-ptscotch=1',
    '--with-scalapack=1',
    '--with-shared-libraries=1',
    '--with-suitesparse-include=/usr/include/suitesparse',
    '--with-suitesparse-lib=[libamd.so,libbtf.so,libcamd.so,libccolamd.so,libcholmod.so,libcolamd.so,libcxsparse.so,libgraphblas.so,libklu.so,libklu_cholmod.so,liblagraph.so,liblagraphx.so,libldl.so,libparu.so,librbio.so,libspex.so,libspqr.so,libsuitesparse_mongoose.so,libsuitesparseconfig.so,libumfpack.so]',
    '--with-superlu-include=/usr/include/superlu',
    '--with-superlu-lib=-lsuperlu',
    '--with-superlu_dist-include=/usr/include/superlu_dist',
    '--with-superlu_dist-lib=-lsuperlu_dist',
    '--with-triangle=1',
    '--with-yaml=1',
    '--with-zfp=1',
    '--with-zlib=1',
    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -flto=auto',
    'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto',
    'FFLAGS=',
    'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
    'MAKEFLAGS=-j4',
    'PETSC_ARCH=linux-c-opt',
  ]
  configure.petsc_configure(configure_options)

==> petsc-3.22.2-1-x86_64.pkg.tar.zst: opt/petsc/linux-c-opt/lib/petsc/conf/reconfigure-linux-c-opt.py <==
#!/usr/bin/python3
if __name__ == '__main__':
  import sys
  import os
  sys.path.insert(0, os.path.abspath('config'))
  import configure
  configure_options = [
    '--prefix=/opt/petsc/linux-c-opt',
    '--with-bison=0',
    '--with-cmake=0',
    '--with-fftw=1',
    '--with-gsl=1',
    '--with-hdf5-fortran-bindings=1',
    '--with-hdf5=1',
    '--with-hypre-include=/usr/include/hypre',
    '--with-hypre-lib=/usr/lib/libHYPRE.so',
    '--with-libjpeg=1',
    '--with-metis=1',
    '--with-mpi-dir=/usr',
    '--with-mpi-f90module-visibility=0',
    '--with-mumps=1',
    '--with-netcdf=1',
    '--with-parmetis=1',
    '--with-petsc4py=1',
    '--with-ptscotch=1',
    '--with-scalapack=1',
    '--with-shared-libraries=1',
    '--with-suitesparse=1',
    '--with-superlu-include=/usr/include/superlu',
    '--with-superlu-lib=-lsuperlu',
    '--with-superlu_dist-include=/usr/include/superlu_dist',
    '--with-superlu_dist-lib=-lsuperlu_dist',
    '--with-triangle=1',
    '--with-yaml=1',
    '--with-zfp=1',
    '--with-zlib=1',
    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto',
    'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto',
    'FFLAGS=',
    'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
    'MAKEFLAGS=-j4',
    'PETSC_ARCH=linux-c-opt',
  ]
  configure.petsc_configure(configure_options)
